@@ -74,6 +74,12 @@ class EdfWriter(object):
     def __exit__(self, exc_type, exc_val, ex_tb):
         self.close()  # cleanup the file
 
+    def __enter__(self):
+        return self
+
+    def __del__(self):
+        self.close()
+
     def __init__(self, file_name, n_channels,
                  file_type=FILETYPE_EDFPLUS):
         """Initialises an EDF file at file_name.
@@ -364,7 +370,10 @@ class EdfWriter(object):
         recording_start_time: datetime object
             Sets the recording start Time
         """
-        self.recording_start_time = recording_start_time
+        if isinstance(recording_start_time,datetime):
+            self.recording_start_time = recording_start_time
+        else:
+            self.recording_start_time = datetime.strptime(recording_start_time,"%d %b %Y %H:%M:%S")
         self.update_header()
 
     def setBirthdate(self, birthdate):
@@ -687,3 +696,4 @@ class EdfWriter(object):
         Closes the file.
         """
         close_file(self.handle)
+        self.handle = -1
